pitchtools.named_pitch_and_clef_to_staff_position_number
========================================================

.. autofunction:: abjad.tools.pitchtools.named_pitch_and_clef_to_staff_position_number.named_pitch_and_clef_to_staff_position_number
